[asterisk-commits] tilghman: trunk r43446 - in /trunk/apps: app_setcallerid.c app_voicemail.c

asterisk-commits at lists.digium.com asterisk-commits at lists.digium.com
Thu Sep 21 13:23:32 MST 2006


Author: tilghman
Date: Thu Sep 21 15:23:32 2006
New Revision: 43446

URL: http://svn.digium.com/view/asterisk?rev=43446&view=rev
Log:
More removal of deprecated stuff

Modified:
    trunk/apps/app_setcallerid.c
    trunk/apps/app_voicemail.c

Modified: trunk/apps/app_setcallerid.c
URL: http://svn.digium.com/view/asterisk/trunk/apps/app_setcallerid.c?rev=43446&r1=43445&r2=43446&view=diff
==============================================================================
--- trunk/apps/app_voicemail.c (original)
+++ trunk/apps/app_voicemail.c Thu Sep 21 15:23:32 2006
@@ -6492,7 +6492,6 @@
 	char *tmp;
 	struct leave_vm_options leave_options;
 	struct ast_flags flags = { 0 };
-	static int deprecate_warning = 0;
 	char *opts[OPT_ARG_ARRAY_SIZE];
 	AST_DECLARE_APP_ARGS(args,
 		AST_APP_ARG(argv0);
@@ -6525,32 +6524,6 @@
 				} else {
 					leave_options.record_gain = (signed char) gain;
 				}
-			}
-		} else {
-			/* old style options parsing */
-			int old = 0;
-			char *orig_argv0 = args.argv0;
-			while (*(args.argv0)) {
-				if (*(args.argv0) == 's') {
-					old = 1;
-					ast_set_flag(&leave_options, OPT_SILENT);
-				} else if (*(args.argv0) == 'b') {
-					old = 1;
-					ast_set_flag(&leave_options, OPT_BUSY_GREETING);
-				} else if (*(args.argv0) == 'u') {
-					old = 1;
-					ast_set_flag(&leave_options, OPT_UNAVAIL_GREETING);
-				} else if (*(args.argv0) == 'j') {
-					old = 1;
-					ast_set_flag(&leave_options, OPT_PRIORITY_JUMP);
-				} else
-					break;
-				(args.argv0)++;
-			}
-			if (!deprecate_warning && old) {
-				deprecate_warning = 1;
-				ast_log(LOG_WARNING, "Prefixing the mailbox with an option is deprecated ('%s').\n", orig_argv0);
-				ast_log(LOG_WARNING, "Please move all leading options to the second argument.\n");
 			}
 		}
 	} else {
@@ -6825,24 +6798,14 @@
 	return NULL;
 }
 
-static struct ast_cli_entry cli_show_voicemail_users_deprecated = {
-	{ "show", "voicemail", "users", NULL },
-	handle_voicemail_show_users, NULL,
-	NULL, complete_voicemail_show_users };
-
-static struct ast_cli_entry cli_show_voicemail_zones_deprecated = {
-	{ "show", "voicemail", "zones", NULL },
-	handle_voicemail_show_zones, NULL,
-	NULL, NULL };
-
 static struct ast_cli_entry cli_voicemail[] = {
 	{ { "voicemail", "list", "users", NULL },
 	handle_voicemail_show_users, "List defined voicemail boxes",
-	voicemail_show_users_help, complete_voicemail_show_users, &cli_show_voicemail_users_deprecated },
+	voicemail_show_users_help, complete_voicemail_show_users, NULL },
 
 	{ { "voicemail", "list", "zones", NULL },
 	handle_voicemail_show_zones, "List zone message formats",
-	voicemail_show_zones_help, NULL, &cli_show_voicemail_zones_deprecated },
+	voicemail_show_zones_help, NULL, NULL },
 };
 
 static int load_config(void)



More information about the asterisk-commits mailing list
--- trunk/apps/app_setcallerid.c (original)
+++ trunk/apps/app_setcallerid.c Thu Sep 21 15:23:32 2006
@@ -18,7 +18,7 @@
 
 /*! \file
  *
  * \brief App to set callerid
  *
  * \author Mark Spencer <markster at digium.com>
  * 
@@ -85,75 +85,16 @@
 	return 0;
 }
 
-static char *app = "SetCallerID";
-
-static char *synopsis = "Set CallerID";
-
-static char *descrip = 
-"  SetCallerID(clid[|a]): Set Caller*ID on a call to a new\n"
-"value.  Sets ANI as well if a flag is used. \n";
-
-static int setcallerid_exec(struct ast_channel *chan, void *data)
-{
-	int res = 0;
-	char *tmp = NULL;
-	char name[256];
-	char num[256];
-	struct ast_module_user *u;
-	char *opt;
-	int anitoo = 0;
-	static int dep_warning = 0;
-
-	if (ast_strlen_zero(data)) {
-		ast_log(LOG_WARNING, "SetCallerID requires an argument!\n");
-		return 0;
-	}
-	
-	u = ast_module_user_add(chan);
-
-	if (!dep_warning) {
-		dep_warning = 1;
-		ast_log(LOG_WARNING, "SetCallerID is deprecated.  Please use Set(CALLERID(all)=...) or Set(CALLERID(ani)=...) instead.\n");
-	}
-
-	tmp = ast_strdupa(data);
-	
-	opt = strchr(tmp, '|');
-	if (opt) {
-		*opt = '\0';
-		opt++;
-		if (*opt == 'a')
-			anitoo = 1;
-	}
-	
-	ast_callerid_split(tmp, name, sizeof(name), num, sizeof(num));
-	ast_set_callerid(chan, num, name, anitoo ? num : NULL);
-
-	ast_module_user_remove(u);
-	
-	return res;
-}
-
 static int unload_module(void)
 {
-	int res;
-
-	res = ast_unregister_application(app2);
-	res |= ast_unregister_application(app);
-
+	int res = ast_unregister_application(app2);
 	ast_module_user_hangup_all();
-
 	return res;
 }
 
 static int load_module(void)
 {
-	int res;
-	
-	res = ast_register_application(app2, setcallerid_pres_exec, synopsis2, descrip2);
-	res |= ast_register_application(app, setcallerid_exec, synopsis, descrip);
-
-	return res;
+	return ast_register_application(app2, setcallerid_pres_exec, synopsis2, descrip2);
 }
 
-AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Set CallerID Application");
+AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Set CallerID Presentation Application");
@@ -18,7 +18,7 @@
 /*! \file
  *
- * \brief App to set callerid
+ * \brief App to set callerid presentation
  *
  * \author Mark Spencer <markster at digium.com>

Modified: trunk/apps/app_voicemail.c
URL: http://svn.digium.com/view/asterisk/trunk/apps/app_voicemail.c?rev=43446&r1=43445&r2=43446&view=diff
==============================================================================